@@ -4,11 +4,13 @@
 Configuration functions for the proteus package for Tryton.
 """
 
+import base64
 import datetime
 import os
 import threading
 import urllib.parse
 import xmlrpc.client
+from contextlib import contextmanager
 from decimal import Decimal
 
 import defusedxml.xmlrpc
@@ -19,10 +21,9 @@ defusedxml.xmlrpc.monkey_patch()
 
 
 def dump_decimal(self, value, write):
-    value = {'__class__': 'Decimal',
-        'decimal': str(value),
-        }
-    self.dump_struct(value, write)
+    write('<value><bigdecimal>')
+    write(str(Decimal(value)))
+    write('</bigdecimal></value>')
 
 
 def dump_date(self, value, write):
@@ -180,9 +181,9 @@ class _TrytondMethod(object):
         self._config = config
 
     def __call__(self, *args, **kwargs):
-        from trytond.rpc import RPC
+        from trytond.rpc import RPC, RPCReturnException
         from trytond.tools import is_instance_method
-        from trytond.transaction import Transaction
+        from trytond.transaction import Transaction, TransactionError
         from trytond.worker import run_task
 
         if self._name in self._object.__rpc__:
@@ -192,23 +193,39 @@ class _TrytondMethod(object):
         else:
             raise TypeError('%s is not callable' % self._name)
 
-        with Transaction().start(self._config.database_name,
-                self._config.user, readonly=rpc.readonly) as transaction:
-            args, kwargs, transaction.context, transaction.timestamp = \
-                rpc.convert(self._object, *args, **kwargs)
-            meth = getattr(self._object, self._name)
-            if (rpc.instantiate is None
-                    or not is_instance_method(self._object, self._name)):
-                result = rpc.result(meth(*args, **kwargs))
-            else:
-                assert rpc.instantiate == 0
-                inst = args.pop(0)
-                if hasattr(inst, self._name):
-                    result = rpc.result(meth(inst, *args, **kwargs))
-                else:
-                    result = [rpc.result(meth(i, *args, **kwargs))
-                        for i in inst]
-            transaction.commit()
+        extras = {}
+        while True:
+            with Transaction().start(self._config.database_name,
+                    self._config.user, readonly=rpc.readonly,
+                    **extras) as transaction:
+                try:
+                    (c_args, c_kwargs,
+                        transaction.context, transaction.timestamp) \
+                            = rpc.convert(self._object, *args, **kwargs)
+                    meth = getattr(self._object, self._name)
+                    if (rpc.instantiate is None
+                            or not is_instance_method(
+                                self._object, self._name)):
+                        result = rpc.result(meth(*c_args, **c_kwargs))
+                    else:
+                        assert rpc.instantiate == 0
+                        inst = c_args.pop(0)
+                        if hasattr(inst, self._name):
+                            result = rpc.result(
+                                meth(inst, *c_args, **c_kwargs))
+                        else:
+                            result = [rpc.result(meth(i, *c_args, **c_kwargs))
+                                for i in inst]
+                except TransactionError as e:
+                    transaction.rollback()
+                    e.fix(extras)
+                    continue
+                except RPCReturnException as e:
+                    transaction.rollback()
+                    transaction.tasks.clear()
+                    result = e.result()
+                transaction.commit()
+            break
         while transaction.tasks:
             task_id = transaction.tasks.pop()
             run_task(self._config.database_name, task_id)
@@ -374,5 +391,30 @@ def set_xmlrpc(url, **kwargs):
     return _CONFIG.current
 
 
+@contextmanager
+def set_xmlrpc_session(
+        url, username, password=None, parameters=None, **kwargs):
+    """
+    Set XML-RPC as backend using session.
+    """
+    if parameters is None:
+        parameters = {}
+    else:
+        parameters = parameters.copy()
+    if password:
+        parameters['password'] = password
+    server = xmlrpc.client.ServerProxy(
+        url, allow_none=True, use_builtin_types=True, **kwargs)
+    session = server.common.db.login(username, parameters)
+    session = ':'.join(map(str, [username] + session))
+    auth = base64.encodebytes(session.encode('utf-8')).decode('ascii')
+    auth = ''.join(auth.split())  # get rid of whitespace
+    kwargs.setdefault('headers', []).append(
+        ('Authorization', 'Session ' + auth))
+    config = set_xmlrpc(url, **kwargs)
+    yield config
+    config.server.common.db.logout()
+
+
 def get_config():
     return _CONFIG.current
