@@ -1,6 +1,7 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 from proteus import Model
+
 from .common import ProteusTestCase
 
 
@@ -72,6 +73,24 @@ class TestModel(ProteusTestCase):
         except AttributeError:
             pass
 
+    def test_many2many_append_unique(self):
+        User = Model.get('res.user')
+        Group = Model.get('res.group')
+        admin, = User.find([('login', '=', 'admin')])
+        group = Group(admin.groups[0].id)
+        admin.groups.append(group)
+
+        self.assertEqual(admin.groups.count(group), 1)
+
+    def test_many2many_extend_unique(self):
+        User = Model.get('res.user')
+        Group = Model.get('res.group')
+        admin, = User.find([('login', '=', 'admin')])
+        group = Group(admin.groups[0].id)
+        admin.groups.extend([group])
+
+        self.assertEqual(admin.groups.count(group), 1)
+
     # TODO test date
 
     def test_reference(self):
@@ -108,6 +127,14 @@ class TestModel(ProteusTestCase):
         self.assertEqual(len(User(groups=[x.id for x in groups]).groups),
                 len(groups))
 
+    def test_assign_unknown_field(self):
+        "Test it is not allowed to assign unknown field"
+        User = Model.get('res.user')
+        user = User()
+
+        with self.assertRaises(AttributeError):
+            user.unknown_field = 'foo'
+
     def test_save(self):
         User = Model.get('res.user')
         test = User()
@@ -291,7 +318,6 @@ class TestModel(ProteusTestCase):
         Group = Model.get('res.group')
         test = Group()
         test.name = 'Test delete'
-        test.login = 'test delete'
         test.save()
         test.delete()
 
